#
# spec file for package ell
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   libell0
Name:           ell
Version:        0.73
Release:        1.1
Summary:        Wireless setup and cryptography library
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://01.org/ell
#Git-Clone:     https://git.kernel.org/pub/scm/libs/ell/ell.git
Source:         https://mirrors.kernel.org/pub/linux/libs/ell/%name-%version.tar.xz
Source2:        https://mirrors.kernel.org/pub/linux/libs/ell/%name-%version.tar.sign
Source3:        %name.keyring
BuildRequires:  gcc-c++
BuildRequires:  libtool >= 2.2
BuildRequires:  pkg-config
BuildRequires:  xz

%description
The "Embedded Linux Library" implements an API for wireless
cryptography actions by using the kernel crypto API.

%package -n %lname
Summary:        Wireless setup and cryptography library
Group:          System/Libraries

%description -n %lname
The "Embedded Linux Library" implements an API for wireless
cryptography actions by using the kernel crypto API.

%package devel
Summary:        Development files for the ELL wireless setup/crypto library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
The "Embedded Linux Library" implements an API for wireless
cryptography actions by using the kernel crypto API.

This subpackage contains libraries and header files for developing
applications that want to make use of ell.

%prep
%autosetup -p1

%build
# This project does not implement proper SONAMing, let alone symbol versioning.
# Force systems into lockstep updates to remedy this.
perl -i -lpe 's{^ELL_0.10}{ELL_%version}' ell/ell.sym

%configure
%make_build

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%check
%make_build check || :

%ldconfig_scriptlets -n %lname

%files -n %lname
%license COPYING
%_libdir/libell.so.*

%files devel
%_libdir/libell.so
%_libdir/pkgconfig/*.pc
%_includedir/ell/

%changelog
* Fri Feb 14 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.73
  * Add support for the Test Anything Protocol.
  * Fix issue with parsing hwdb.bin child structures.
* Mon Dec  2 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.71
  * Build fixes for GCC's new default -std=c23 mode.
* Tue Oct  1 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.69
  * Add support for getting remaining microseconds left on a
    timer.
  * Add support for setting link MTU on a network interface.
  version 0.68:
  * Fix issue with string allocation growth strategy.
  * Add support for netlink helper functions.
* Tue Jul  9 2024 Dirk Müller <dmueller@suse.com>
- update to 0.67:
  * Add support for handling sysctl char settings.
* Fri Jun  7 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.66
  * Fix issue with handling event callback when stopping ACD.
  * Fix issue with handling ICMPv6 DNS and domain lists.
  * Add support for notification lists.
  version 0.65:
  * Add support for bitmaps manipulation macros.
* Mon Apr  1 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.64
  * Fix issue with casting in C++ environment.
  * Fix issue with ASCII string upper and lower helpers.
* Sat Mar 23 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.63
  * Fix issue with handling ending boundary of the PEM.
* Sat Feb 17 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.62
  * Add support for cleanup functions and macros.
  * Add support for setting DHCP max attempts.
* Wed Dec 27 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.61
  * netconfig: Always set DHCP MAC address on start
  * netlink: Add workaround for missing NLM_F_ACK_TLVS
    and NLM_F_CAPPED
* Tue Nov 21 2023 Dirk Müller <dmueller@suse.com>
- update to 0.60:
  * Fix issue with missing NETLINK_EXT_ACK definition.
  * Fix issue with incorrect derivation of ECC compressed points.
  * Add support for ECC usage from SPAKE2+ key exchange protocol.
* Wed Nov  1 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.59
  * Add l_safe_ato* functions to the exported symbol list.
* Tue Aug 29 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.58
  * Add support for handling sysctl settings.
* Mon Jun 19 2023 Dirk Müller <dmueller@suse.com>
- update to 0.57:
  * Fix issue with handling Generic Netlink cancel requests.
* Wed Jan 25 2023 Paolo Stivanin <info@paolostivanin.com>
- update to 0.56:
  * Add support for TLS session resume interfaces.
* Fri Dec 23 2022 Dirk Müller <dmueller@suse.com>
- update to 0.55:
  * Fix issue with DHCP and blocked unicast requests.
* Sat Dec  3 2022 Dirk Müller <dmueller@suse.com>
- update to 0.54:
  * Add support for DHCPv6 SLAAC address creation.
  * Add support for control of optimistic DAD feature.
  * Add support for checking validity dates of certificates.
  * Add support for RFC 5746 Secure Renegotiation.
* Tue Sep 13 2022 Dirk Müller <dmueller@suse.com>
- update to 0.53:
  * Add support for EC based certificates.
* Mon Jul 18 2022 Dirk Müller <dmueller@suse.com>
- update to 0.52:
  * Fix issue with using PTRDIFF_MAX constant.
  * Fix issue with accepting FD 0 as epoll_fd.
  * Fix issue with setting bound time before emitting event.
  * Fix issue with starting ACD before committing static IPv4.
  * Fix issue with waiting for link-local address before DHCPv6.
* Mon Jul 11 2022 Dirk Müller <dmueller@suse.com>
- update to 0.51:
  * Fix issue with handling bad prefixes per RFC4862
  * Fix issue with handling DHCP retransmission timers
  * Add support for DHCP override and static IP API
* Tue Apr 26 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.50
  * dbus: Fix use-after-free crash when removing objects
* Fri Feb 25 2022 Paolo Stivanin <info@paolostivanin.com>
- update to 0.49:
  * Fix issue with multiple offers from the same DHCP server.
  * Fix issue with Base64 decoding and bytes consumed validation.
* Mon Jan 24 2022 Dirk Müller <dmueller@suse.com>
- update to 0.48:
  * Fix issue with memory leaking from ICMPv6 RA.
  * Fix issue with memory leaking from DHCP leases.
  * Fix issue with NULL terminating of Base64 encoding.
* Mon Nov 22 2021 Malte Ohmstede <malte.ohmstede@gmail.com>
- update to release 0.46
  * Fix issue with DHCP server when OPTION_ROUTER is not configured.
  * Fix issue with DHCP obtained lease to retrieve it properly.
* Fri Nov  5 2021 Malte Ohmstede <malte.ohmstede@gmail.com>
-update to release 0.45
  * Fix issue with ICMPv6 and handling re-entrantly callbacks.
* Sun Sep 19 2021 Malte Ohmstede <malte.ohmstede@gmail.com>
- update to release 0.44
  * Fix issue with allowing zero byte input for AEAD cipher.
  * Fix issue with filling in DNS info in DHCP lease objects.
  * Add support neighbor discovery utility helpers.
* Tue Sep  7 2021 Malte Ohmstede <malte.ohmstede@gmail.com>
- Update to release 0.43
  * Add support for DHCP Rapid Commit feature.
  * Add support for DHCP authorative mode feature.
* Thu Aug 19 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.42
  * Add support for constant time security functions.
  * Add support for manipulating DHCP leases.
* Mon Jun 21 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.41
  * Fix issue with endianness of DHCP packets.
  * Fix issue with lease handling of the DHCP server.
* Tue May 11 2021 Dirk Müller <dmueller@suse.com>
- update to 0.40:
  * Fix issue with handling failure from missing CA certificates.
  * Fix issue with handling DBus.Introspectable queries.
* Tue Apr  6 2021 Dirk Müller <dmueller@suse.com>
- update to 0.39:
  * Add support for serialized test execution framework
* Thu Feb 18 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to release 0.38 :
  * Fix issue with DHCP v6 Rapid Commit option check.
  * Fix issue with handling RFC8018/RFC1423 padding.
  * Fix issue with D-Bus filter messages with no interfaces set.
  * Add support for PKCS#12 certification loading.
* Sun Jan 10 2021 Maciej Borzecki <maciek.borzecki@gmail.com>
- Update to release 0.36
  * Fix issue with strict netlink attribute validation.
  * Fix issue with DUID generation for DHCPv6.
  * Add support for Address Conflict Detection.
  * Add support for PKCS#12 algorithms handling.
  * Add support for PKCS#12 key derivation algorithm.
  * Add support for RC2 and ARC4 cipher suites.
* Wed Dec 23 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.35
  * Add support for DHCP v6 Rapid Commit.
  * Add support for ICMP v6 implementation.
  * Add support for PKCS#1 formatted private keys.
* Sat Sep  5 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.33
  * Fixed an issue with overflow in DHCP lease T2 computation.
  * Added support for DHCPv6 client implementation.
  * Removed support for ARC4 and RC4 cipher suites.
* Mon Jun 15 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.32
  * dbus: call destroy function in l_dbus_remove_watch
* Wed Apr 15 2020 Harry ten Berge <htenberge@gmail.com>
- ver 0.31:
  * Fix issue with verification of the second certificate in chain.
  * Fix issue with handling trusted CA matching in verification.
* Thu Mar 26 2020 Harry ten Berge <htenberge@gmail.com> 
- ver 0.30:
  * Fix issue with missing export of RTNL helper functions.
- ver 0.29:
  * Fix issue with time overflow on 32-bit systems.
  * Add support for RTNL helper functionality.
* Mon Feb 10 2020 Harry ten Berge <htenberge@gmail.com>
- ver 0.28:
  * Fix issue with NULL check of D-Bus proxy for method calls.
  * Add support for emitting D-Bus property changes on demand.
  * Add support for reporting file attribute changes.
* Thu Jan  2 2020 Harry ten Berge <htenberge@gmail.com>
- ver 0.27:
  * Fix issue with data overflow and multiple PEMs.
  * Fix issue with handling DHCP lease expiration.
* Wed Oct 30 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.26:
  * Fix issue with memory leak and TLS certificates.
  * Fix issue with buffer size and TLS PRF handling.
  * Add support for D-Bus non-root ObjectManager.
- Changes from version 0.25:
  * Fix issue with stopping DHCP client and owner notification.
  * Fix issue with time calculation overflow and DHCP.
- Changes from version 0.24:
  * Add support for extended groups in settings files.
* Fri Sep 20 2019 Xaver Hellauer <xaver@hellauer.bayern>
- ver 0.23:
  * Add support for checking if uintset is empty.
- ver 0.22:
  * Fix issue with DHCP and T1 timeout handling.
  * Fix issue with escape characters in peer identity string.
  * Add support for setting peer certificate's subject CN mask.
* Sun Aug 11 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 0.21
  * Fix issue with resetting DHCP lease on client stop.
  * Add support for GPIO helper functionality.
* Mon May 27 2019 Xaver Hellauer <xaver@hellauer.bayern>
- ver 0.20:
  * Fix issue with DHCP client and handling renewing state.
  * Fix issue with DHCP client and handling rebinding state.
  * Fix issue with DHCP client and recommended retry timeouts.
  * Fix issue with Generic Netlink and family discovery.
- ver 0.19:
  * Fix issue with termination of Generic Netlink names.
  * Fix issue with handling ECC scalar initialization.
* Thu Apr  4 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.18:
  * Fix an issue with handling revocation of keys.
  * Add support for the TLS Signature Algorithms extension.
  * Add support for the TLS version range configuration.
  * Add support for time utility functions.
- Remove unsigned-char.patch: fixed upstream.
* Fri Mar 15 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 0.17
  * Added support for TLS Supported Groups extension, TLS Hello
    extension feature, and for ECC and ECDH functionality.
* Thu Jan 31 2019 schwab@suse.de
- unsigned-char.patch: don't depend on signedness of char
* Thu Dec 13 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 0.16
  * Add support for watchdog notification handling from systemd.
  * Add support for generic X.509 certificate utilities.
  * Add support for using AEAD ciphers for TLS.
* Sun Nov 18 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 0.15
  * Fix an issue with signals not being registered properly.
* Tue Nov 13 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 0.14
  * Fix issue with TLS failure handling.
  * Fix issue with loading empty settings file.
  * Fix issue with generic netlink message sizes.
  * Add support for filesystem watch functionality.
  * Fix issue with missing filesystem watch notifications.
  * Fix issue with buffer overrun and PBKDF2 support.
  * Add support for string argument parsing.
  * Fix issue with D-Bus subpath comparisons in object tree walk.
  * Fix issue with D-Bus InterfacesAdded on new ObjectManager
    addition.
  * Fix issue with verifying total length of certificates.
  * Fix issue with loading v2 and v3 formatted hwdb.bin files.
  * Fix issue with handling EPOLLHUP and EPOLLERR in IO watch.
  * Fix issue with closing of the fd inside IO watch handlers.
  * Fix issue with initialization of struct keyctl_dh_params.
  * Fix issue with unexported public API symbols.
  * Fix issue with handling netlink error return values.
  * Fix issue with handling hashmap removing of last entry.
  * Fix issue with handling zero-length secret for PRF.
  * Add support for directory watch interface.
  * Fix issue with return value of l_getrandom_is_supported.
  * Fix issue with supporting l_genl_family_set_unicast_handler.
  * Fix issue with utilizing single shared signalfd file descriptor.
* Tue Jun  5 2018 seife+obs@b1-systems.com
- update to version 0.5 (released 2018-05-05)
- ell >= 0.3 is required for new bluez versions
- ver 0.5:
  - Fix issue with missing exported debug symbols.
  - Add support for DHCP client library.
- ver 0.4:
  - Fix issue with propagate AEAD cipher failures.
  - Fix issue with AAD length and AEAD result reads.
- ver 0.3:
  - Fix issue with IO handling and re-entrancy.
  - Add support for D-Bus client proxy interface.
- ver 0.2:
  - Add support for mainloop integration functions.
  - Add support for PKCS#5 key derivation functions.
  - Add support for additional checksum and cipher types.
- ver 0.1:
  - Initial public release.
* Fri Nov 11 2016 jengelh@inai.de
- Initial package (version 0~1304) for build.opensuse.org
